@@ -15,6 +15,9 @@ class DatoEnhancer(object):
     target_column = ""
 
     def __init__(self, dato_mapper: DatoMapper):
+        """Create DatoTrainer object for training a generative model for the mapped input data.
+        Args:
+            dato_mapper: the DatoMapper object for the input data."""
         dato_mapper.next_step_validation()
         self.dato_mapper = dato_mapper
 
@@ -49,7 +52,7 @@ class DatoEnhancer(object):
                                                   business_unit_id=self.dato_mapper.business_unit_id,
                                                   project_id=self.dato_mapper.project_id,
                                                   flow_id=self.dato_mapper.flow_id,
-                                                  step_type=step_types.ML_SPLIT_AND_EVALUATE,
+                                                  step_type=step_types.ML_TRAIN_AND_GENERATE,
                                                   train_id=self.train_id)
         if status == general.ERROR:
             raise Exception("Trainer Failed")
@@ -57,6 +60,14 @@ class DatoEnhancer(object):
         print(train)
         self.model_id = train[general.MODELS][0][general.ID]
 
+    def get_generated_data(self) -> None:
+        self.restore_validation()
+        print(common_helper.get_generated_zip(datomizer=self.dato_mapper.datomizer,
+                                              business_unit_id=self.dato_mapper.business_unit_id,
+                                              project_id=self.dato_mapper.project_id,
+                                              flow_id=self.dato_mapper.flow_id,
+                                              train_id=self.train_id))
+
     def get_generated_data_csv(self, table_name: str = None) -> io.StringIO:
         """Get the generated data in a csv format.
                 Args:
